#!/usr/bin/env bash
#
# Get Image of DynamoDB capacity from CloudWatch
#
# Requirements
#   awscli aws-cli/1.14.44 or later
#
# ref: get-metric-widget-image — AWS CLI Command Reference: https://docs.aws.amazon.com/cli/latest/reference/cloudwatch/get-metric-widget-image.html

function get_image_dynamodb_capacity() {
  local image_file=$1
  local aws_profile=$2
  local aws_region=$3
  local dynamodb_table=$4
  local title="${dynamodb_table} (Count/Second)"
  local width=720
  local height=480
  local yAxis_max=50

  aws cloudwatch get-metric-widget-image \
    --profile ${aws_profile} \
    --region ${aws_region}  \
    --query 'MetricWidgetImage' \
    --output text \
    --metric-widget "$(printf '{
      "title": "%s",
      "width": %s,
      "height": %s,
      "stacked": false,
      "legend": {"position": "right"},
      "start": "-P14D",
      "end":" PT0H",
      "timezone": "+0000",
      "period": 60,
      "yAxis":{
        "left": {"min": 0, "max": %s},
        "right": {"min": 0}
      },
      "metrics":[
        [
          "AWS/DynamoDB",
          "ConsumedReadCapacityUnits",
          "TableName",
          "%s",
          {
            "id": "m1",
            "stat": "Sum",
            "label": "Sum",
            "visible": false
          }
        ],
        [
          {
            "id": "e1",
            "expression": "RATE(m1)",
            "label": "ConsumedReadCapacityUnits",
            "visible": true
          }
        ],
        [
          "AWS/DynamoDB",
          "ConsumedWriteCapacityUnits",
          "TableName",
          "%s",
          {
            "id": "m2",
            "stat": "Sum",
            "label": "Sum",
            "visible": false
          }
        ],
        [
          {
            "id": "e2",
            "expression": "RATE(m2)",
            "label": "ConsumedWriteCapacityUnits",
            "visible": true
          }
        ]
      ]
    }' "${title}" "${width}" "${height}" "${yAxis_max}" "${dynamodb_table}" "${dynamodb_table}" )" | base64 --decode > $image_file
}

AWS_PROFILE=example
AWS_REGION=ap-northeast-1
DYNAMODB_TABLE=TestTable
IMAGE_FILE=./dynamodb_capacity.${DYNAMODB_TABLE}.png

get_image_dynamodb_capacity "${IMAGE_FILE}" "${AWS_PROFILE}" "${AWS_REGION}" "${DYNAMODB_TABLE}"
